1.0 (14-Apr-2017)
-----------------
This is the first release intended to use. The Change log will begin starting with this release.

0.1 (experimental release)
--------------------------
This release was not intended to be used, but the verisioning scheme in the development branch required a tagged commit.
